4.6. umbra.components.addons.traceUi.models — Umbra 1.0.9 documentation

# 4.6. umbra.components.addons.traceUi.models

models.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `umbra.components.factory.traceUi.traceUi.TraceUi` Component Interface class Models.

Others:

## 4.6.1. Module Attributes

`umbra.components.addons.traceUi.models.` `LOGGER`

## 4.6.2. Classes

class `umbra.components.addons.traceUi.models.` `ModulesModel`(parent=None, rootNode=None, horizontalHeaders=None, verticalHeaders=None, defaultNode=None)

  Bases: `umbra.ui.models.GraphModel`

  Defines the Model used the by `umbra.components.factory.traceUi.traceUi.TraceUi` Component Interface class.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. rootNode (AbstractCompositeNode) – Root node. horizontalHeaders (OrderedDict) – Headers. verticalHeaders (OrderedDict) – Headers. defaultNode (GraphModelNode) – Default node.

  `initializeModel`(rootNode)

    Initializes the Model using given root node.

    Parameters: | rootNode (DefaultNode) – Graph root node.
    Returns: | Method success
    Return type: | bool